# pangeo-forge

![CI](https://github.com/pangeo-forge/pangeo-forge/workflows/CI/badge.svg)
![Codecov](https://img.shields.io/codecov/c/github/pangeo-forge/pangeo-forge)
[![Documentation Status](https://readthedocs.org/projects/pangeo-forge/badge/?version=latest)](https://pangeo-forge.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

__pangeo-forge__ is an open-source tool designed to aid the extraction, transformation, and loading of datasets. The goal of pangeo-forge is to make it easy to extract datasets from traditional data repositories and deposit them into cloud object storage in analysis-ready, cloud-optimized format.

pangeo-forge is inspired by [conda-forge](https://conda-forge.org/), a community-led collection of recipes for building [Conda](https://docs.conda.io/en/latest/) packages. We hope that pangeo-forge can play the same role for datasets.

## Documentation

More can be learned about pangeo-forge, its progress, and related subprojects in its [official documentation](https://pangeo-forge.readthedocs.io).

## Contributing

pangeo-forge is still early in development - there are several ways to contribute:

1. [Create a recipe](https://pangeo-forge.readthedocs.io/en/latest/contribute.html) for a dataset you are interested in
2. Open an issue or pull request here or in any of the related subprojects ([pangeo-smithy](https://github.com/pangeo-forge/pangeo-smithy), [staged-recipes](https://github.com/pangeo-forge/staged-recipes))
3. Check out the project [roadmap](https://github.com/pangeo-forge/roadmap)

## Get in touch

Discussions on pangeo-forge are generally hosted biweekly on Mondays at 7pm UTC via [Whereby](https://whereby.com/pangeo). More details on the scheduling of these meetings can be found [here](https://github.com/pangeo-forge/roadmap/issues/3).

## License

This project is licensed under the [Apache License, Version 2.0](https://github.com/pangeo-forge/pangeo-forge/blob/master/LICENSE).
